dnl expat.m4 -- Find the path to expat library
dnl $Id$
dnl
dnl This file provides AC_CHECK_LIBEXPAT, which defines the --with-expat-dir
dnl command-line option and probes for libexpat in that directory if it
dnl is used.
dnl
dnl If --with-libexpat-dir is not supplied, it probes in the default locations
dnl /usr and /usr/local
dnl
dnl It then makes sure that libexpat will link, and exports EXPAT_LDFLAGS,
dnl EXPAT_CPPFLAGS, and EXPAT_LIBS

AC_DEFUN([AC_CHECK_LIBEXPAT], [

dnl header file to search for
headerfile=expat.h

dnl libtool library file to search for
la_libfile=libexpat.la

dnl usual shared object file and function to search for
so_libfile=expat
so_func_search=XML_ParserCreate

dnl define configure command line argument
AC_ARG_WITH([expat-dir],
    [AC_HELP_STRING(--with-expat-dir=PATH,
        [Path to expat installation])],
    [ DIR="$with_expat_dir" ],
    [ DIR=]
)

AC_MSG_CHECKING([for $headerfile])
if test "x$DIR" = x; then
    dnl if expat-dir was not specified, check default header location
    for dir in /usr/local /usr ; do
        if test -f "$dir/include/$headerfile" ; then
            found=yes
            AC_MSG_RESULT([$dir/include/$headerfile])
            break
        fi
    done
    if test "x$found" = "x"; then
        AC_MSG_ERROR([$headerfile not found])
    fi
else
    dnl check whether DIR/include contains header. If not, bail out
    if test -f "$DIR/include/$headerfile" ; then
        local_CPPFLAGS="-I$DIR/include"
        AC_MSG_RESULT([$DIR/include/$headerfile])
    else
        AC_MSG_ERROR([Could not find $DIR/include/$headerfile])
    fi
fi


dnl Additional check whether the header file can be preprocessed
old_CPPFLAGS="$CPPFLAGS"
CPPFLAGS="$local_CPPFLAGS"
AC_PREPROC_IFELSE([AC_LANG_SOURCE([[#include <$headerfile>]])],
    [],
    [AC_MSG_ERROR([Something is wrong with your library installation])]
)
CPPFLAGS="$old_CPPFLAGS"

dnl Check for supplied libtool library
if test "x$la_libfile" != x; then
    AC_MSG_CHECKING([for $la_libfile])
    la_LIBS=
    for dir in "$DIR" /usr; do
        lib_la="$dir/lib/$la_libfile"
        if test -f "$lib_la"; then
            la_LIBS="$lib_la"
            AC_MSG_RESULT([$la_LIBS])
            break;
        fi
    done

    if test "x$la_LIBS" = x; then
         AC_MSG_RESULT(not found)
    fi
fi

if test "x$so_libfile" != x; then
    old_LIBS="$LIBS"
    LIBS=
    old_LDFLAGS="$LDFLAGS"
    if test "x$DIR" = x; then
        LDFLAGS=
    else
        LDFLAGS="-L$DIR"
    fi
    AC_CHECK_LIB($so_libfile, $so_func_search)
    if test "x$LIBS" != "x"; then
        so_LIBS="$LIBS"
        local_LDFLAGS="$LDFLAGS"
    fi
    LIBS="$old_LIBS"
    LDFLAGS="$old_LDFLAGS"
fi

if test "x$la_LIBS" != x; then
    local_LIBS="$la_LIBS"
    local_LDFLAGS=
elif test "x$so_LIBS" != x; then
    local_LIBS="$so_LIBS"
else
    AC_MSG_ERROR([could not find library to link to])
fi

EXPAT_CPPFLAGS="$local_CPPFLAGS"
EXPAT_LDFLAGS="$local_LDFLAGS"
EXPAT_LIBS="$local_LIBS"

dnl AC_MSG_NOTICE([
dnl EXPAT_CPPFLAGS = "$EXPAT_CPPFLAGS"
dnl EXPAT_LDFLAGS = "$EXPAT_LDFLAGS"
dnl EXPAT_LIBS = "$EXPAT_LIBS"
dnl ])

AC_SUBST([EXPAT_CPPFLAGS])
AC_SUBST([EXPAT_LDFLAGS])
AC_SUBST([EXPAT_LIBS])

])
